searchData={"items":[{"type":"module","title":"PrefixedApiKey","doc":"`PrefixedAPIKey` is a quick Elixir port of Seam's Javascript\n[Prefixed API Key](https://github.com/seamapi/prefixed-api-key) library.\nIt creates and verifies simple, random authentication tokens that have two useful prefix parts.\n\nThis version is a little different (it has a smaller set of functions and uses a slightly bigger character set)\nbut appears to be compatible with the original.","ref":"PrefixedApiKey.html"},{"type":"module","title":"Overview - PrefixedApiKey","doc":"Example key:\n> `mycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG`\n\nSeam-style API Keys have these benefits:\n\n- Double clicking the api key usually selects the entire api key\n- The alphabet is standard across languages (the original uses Base58, this uses a slightly larger alphanumeric ASCII set)\n- They are shorter than hex and base32 api keys\n- They have prefixes [allowing secret scanning by github](https://docs.github.com/en/code-security/secret-scanning/about-secret-scanning)\n- They have a hashed component so the server doesn't need to store the api key (reducing attack surface)\n- They have unhashed short tokens which can be mutually used by the server and key bearer/customer to identify the api key\n- They default to roughly the same number of entropy bits as UUIDv4","ref":"PrefixedApiKey.html#module-overview"},{"type":"module","title":"The Format - PrefixedApiKey","doc":"Prefixed API Keys look like this:\n\n```\nmycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG\n```\n\nComponents:\n\n```\nmycompany ..._...  BRTRKFsL ..._...  51FwqftsmMDHHbJAMEXXHCgG\n^                  ^                 ^\nPrefix             Short Token       Long Token\n```\n\n- The *Prefix* is used to identify the company or service creating the API Key.\nThis is very helpful in secret scanning.\n- The *Short Token* is stored by both the server and the key bearer/customer, it\ncan be used to identify an API key in logs or displayed on a customer's\ndashboard. A token can be deny-listed by its short token.\n- The *Long Token* is how we authenticate this key. The long token is never stored\non the server, but a hash of it is stored on the server. When we receive an\nincoming request, we search our database for `short_token` and `hash`.","ref":"PrefixedApiKey.html#module-the-format"},{"type":"module","title":"Example - PrefixedApiKey","doc":"iex> {:ok, key} = PrefixedApiKey.generate(\"example\")\n    iex> api_key = key.api_key\n    iex> {:ok, _key} = PrefixedApiKey.parse(api_key)\n\n    iex> PrefixedApiKey.verify?(\"myapp_ZLXZ3PYn_E34CUQSRtlmf0CMLsKFjMOf7\", \"d5264a8fef50459c35306c35396c446cf88f8755c06ff70c341eb3fbd606ca44\")\n    true","ref":"PrefixedApiKey.html#module-example"},{"type":"function","title":"PrefixedApiKey.generate/1","doc":"Generates a new API key, using the specified prefix\n\nUse the prefix to identify keys for *your* application.","ref":"PrefixedApiKey.html#generate/1"},{"type":"function","title":"Example - PrefixedApiKey.generate/1","doc":"iex> PrefixedApiKey.generate(\"doormouse\")","ref":"PrefixedApiKey.html#generate/1-example"},{"type":"function","title":"PrefixedApiKey.parse/1","doc":"Parses a prefixed API Key string into its component parts, and produces a hash of the long token.\n\n(You can also parse an already-parsed key)","ref":"PrefixedApiKey.html#parse/1"},{"type":"function","title":"Example - PrefixedApiKey.parse/1","doc":"iex> PrefixedApiKey.parse(\"mycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG\")\n   {:ok, %PrefixedApiKey{\n             prefix: \"mycompany\",\n             short_token: \"BRTRKFsL\",\n             long_token: \"51FwqftsmMDHHbJAMEXXHCgG\",\n             api_key: \"mycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG\",\n             hash: \"d70d981d87b449c107327c2a2afbf00d4b58070d6ba571aac35d7ea3e7c79f37\"\n           }}","ref":"PrefixedApiKey.html#parse/1-example"},{"type":"type","title":"PrefixedApiKey.t/0","doc":"","ref":"PrefixedApiKey.html#t:t/0"},{"type":"function","title":"PrefixedApiKey.verify?/2","doc":"Compares an Prefixed API Key string (or struct) to a hash and short token that you have previously stored, for verification of the key.","ref":"PrefixedApiKey.html#verify?/2"},{"type":"function","title":"Example - PrefixedApiKey.verify?/2","doc":"iex> PrefixedApiKey.verify?(\n    ...>   \"mycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG\",\n    ...>   \"d70d981d87b449c107327c2a2afbf00d4b58070d6ba571aac35d7ea3e7c79f37\",\n    ...>   \"BRTRKFsL\")\n    true","ref":"PrefixedApiKey.html#verify?/2-example"},{"type":"function","title":"PrefixedApiKey.verify?/3","doc":"Compares an Prefixed API Key string (or struct) to a hash you have previously stored, for verification of the key.","ref":"PrefixedApiKey.html#verify?/3"},{"type":"function","title":"Example - PrefixedApiKey.verify?/3","doc":"iex> PrefixedApiKey.verify?(\n    ...>        \"mycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG\",\n    ...>        \"d70d981d87b449c107327c2a2afbf00d4b58070d6ba571aac35d7ea3e7c79f37\")\n    true","ref":"PrefixedApiKey.html#verify?/3-example"},{"type":"module","title":"PrefixedApiKey.LongToken.Bits","doc":"","ref":"PrefixedApiKey.LongToken.Bits.html"},{"type":"function","title":"PrefixedApiKey.LongToken.Bits.generate/0","doc":"","ref":"PrefixedApiKey.LongToken.Bits.html#generate/0"},{"type":"function","title":"PrefixedApiKey.LongToken.Bits.reset/0","doc":"","ref":"PrefixedApiKey.LongToken.Bits.html#reset/0"},{"type":"module","title":"PrefixedApiKey.LongToken.Decoder","doc":"","ref":"PrefixedApiKey.LongToken.Decoder.html"},{"type":"function","title":"PrefixedApiKey.LongToken.Decoder.decode/1","doc":"","ref":"PrefixedApiKey.LongToken.Decoder.html#decode/1"},{"type":"function","title":"PrefixedApiKey.LongToken.Decoder.decode_pair/1","doc":"","ref":"PrefixedApiKey.LongToken.Decoder.html#decode_pair/1"},{"type":"function","title":"PrefixedApiKey.LongToken.Decoder.decode_single/1","doc":"","ref":"PrefixedApiKey.LongToken.Decoder.html#decode_single/1"},{"type":"module","title":"PrefixedApiKey.LongToken.Encoder","doc":"","ref":"PrefixedApiKey.LongToken.Encoder.html"},{"type":"function","title":"PrefixedApiKey.LongToken.Encoder.encode/1","doc":"","ref":"PrefixedApiKey.LongToken.Encoder.html#encode/1"},{"type":"module","title":"PrefixedApiKey.ShortToken.Bits","doc":"","ref":"PrefixedApiKey.ShortToken.Bits.html"},{"type":"function","title":"PrefixedApiKey.ShortToken.Bits.generate/0","doc":"","ref":"PrefixedApiKey.ShortToken.Bits.html#generate/0"},{"type":"function","title":"PrefixedApiKey.ShortToken.Bits.reset/0","doc":"","ref":"PrefixedApiKey.ShortToken.Bits.html#reset/0"},{"type":"module","title":"PrefixedApiKey.ShortToken.Decoder","doc":"","ref":"PrefixedApiKey.ShortToken.Decoder.html"},{"type":"function","title":"PrefixedApiKey.ShortToken.Decoder.decode/1","doc":"","ref":"PrefixedApiKey.ShortToken.Decoder.html#decode/1"},{"type":"function","title":"PrefixedApiKey.ShortToken.Decoder.decode_pair/1","doc":"","ref":"PrefixedApiKey.ShortToken.Decoder.html#decode_pair/1"},{"type":"function","title":"PrefixedApiKey.ShortToken.Decoder.decode_single/1","doc":"","ref":"PrefixedApiKey.ShortToken.Decoder.html#decode_single/1"},{"type":"module","title":"PrefixedApiKey.ShortToken.Encoder","doc":"","ref":"PrefixedApiKey.ShortToken.Encoder.html"},{"type":"function","title":"PrefixedApiKey.ShortToken.Encoder.encode/1","doc":"","ref":"PrefixedApiKey.ShortToken.Encoder.html#encode/1"},{"type":"extras","title":"PrefixedAPIKey","doc":"# PrefixedAPIKey\n\n`PrefixedAPIKey` is a quick Elixir port of Seam's Javascript \n[Prefixed API Key](https://github.com/seamapi/prefixed-api-key) library. \nIt creates and verifies simple, random authentication tokens that have two useful prefix parts.\n\nThis version is a little different (it has a smaller set of functions and uses a slightly bigger character set) \nbut appears to be compatible with the original.","ref":"readme.html"},{"type":"extras","title":"Installation - PrefixedAPIKey","doc":"The package can be installed by adding `prefixed_api_key` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:prefixed_api_key, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Overview - PrefixedAPIKey","doc":"Example key:\n> `mycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG`\n\nSeam-style API Keys have these benefits:\n\n- Double clicking the api key usually selects the entire api key\n- The alphabet is standard across languages (the original uses Base58, this uses a slightly larger alphanumeric ASCII set)\n- They are shorter than hex and base32 api keys\n- They have prefixes [allowing secret scanning by github](https://docs.github.com/en/code-security/secret-scanning/about-secret-scanning)\n- They have a hashed component so the server doesn't need to store the api key (reducing attack surface)\n- They have unhashed short tokens which can be mutually used by the server and key bearer/customer to identify the api key\n- They default to roughly the same number of entropy bits as UUIDv4","ref":"readme.html#overview"},{"type":"extras","title":"The Format - PrefixedAPIKey","doc":"Prefixed API Keys look like this:\n\n```\nmycompany_BRTRKFsL_51FwqftsmMDHHbJAMEXXHCgG\n```\n\nComponents:\n\n```\nmycompany ..._...  BRTRKFsL ..._...  51FwqftsmMDHHbJAMEXXHCgG\n^                  ^                 ^\nPrefix             Short Token       Long Token\n```\n\n- The *Prefix* is used to identify the company or service creating the API Key.\n  This is very helpful in secret scanning.\n- The *Short Token* is stored by both the server and the key bearer/customer, it\n  can be used to identify an API key in logs or displayed on a customer's\n  dashboard. A token can be deny-listed by its short token.\n- The *Long Token* is how we authenticate this key. The long token is never stored\n  on the server, but a hash of it is stored on the server. When we receive an\n  incoming request, we search our database for `short_token` and `hash`.","ref":"readme.html#the-format"},{"type":"extras","title":"Examples - PrefixedAPIKey","doc":"```elixir\n\n    {:ok, key} = PrefixedApiKey.generate(\"myapp\")\n    # => \n    #    {:ok,\n    #      %PrefixedApiKey{\n    #        api_key: \"myapp_ZLXZ3PYn_E34CUQSRtlmf0CMLsKFjMOf7\",\n    #        hash: \"d5264a8fef50459c35306c35396c446cf88f8755c06ff70c341eb3fbd606ca44\",\n    #        long_token: \"E34CUQSRtlmf0CMLsKFjMOf7\",\n    #        prefix: \"myapp\",\n    #        short_token: \"ZLXZ3PYn\"\n    #      }}\n\n    key.api_key\n    # => \"myapp_ZLXZ3PYn_E34CUQSRtlmf0CMLsKFjMOf7\"\n    \n    {:ok, key} = PrefixedApiKey.parse(\"myapp_ZLXZ3PYn_E34CUQSRtlmf0CMLsKFjMOf7\")\n    # => \n    #    {:ok,\n    #      %PrefixedApiKey{\n    #        api_key: \"myapp_ZLXZ3PYn_E34CUQSRtlmf0CMLsKFjMOf7\",\n    #        hash: \"d5264a8fef50459c35306c35396c446cf88f8755c06ff70c341eb3fbd606ca44\",\n    #        long_token: \"E34CUQSRtlmf0CMLsKFjMOf7\",\n    #        prefix: \"myapp\",\n    #        short_token: \"ZLXZ3PYn\"\n    #      }}\n\n    PrefixedApiKey.verify?(\"myapp_ZLXZ3PYn_E34CUQSRtlmf0CMLsKFjMOf7\", \"d5264a8fef50459c35306c35396c446cf88f8755c06ff70c341eb3fbd606ca44\")\n    # => true\n\n```","ref":"readme.html#examples"},{"type":"extras","title":"API Documentation - PrefixedAPIKey","doc":"Full API documentation can be found at\n[https://hexdocs.pm/prefixed_api_key](https://hexdocs.pm/prefixed_api_key).","ref":"readme.html#api-documentation"},{"type":"extras","title":"Contributing - PrefixedAPIKey","doc":"You can request new features by creating an [issue](https://github.com/Digital-Identity-Labs/prefixed_api_key/issues),\nor submit a [pull request](https://github.com/Digital-Identity-Labs/prefixed_api_key/pulls) with your contribution.\n\nThanks to @stillwondering and @Rodeoclash for patches and suggestions!","ref":"readme.html#contributing"},{"type":"extras","title":"References - PrefixedAPIKey","doc":"* The original [Prefixed API Key](https://github.com/seamapi/prefixed-api-key)\n* [Discussion on the original library at Hacker News](https://news.ycombinator.com/item?id=31333933#31336542)\n* secure_compare function was borrowed from [Plug Crypto](https://github.com/elixir-plug/plug_crypto)","ref":"readme.html#references"},{"type":"extras","title":"Alternatives - PrefixedAPIKey","doc":"* [Context ID](https://hex.pm/packages/context_id)\n* [Pika](https://github.com/ArtieFuzzz/pika)\n* [Prefixed ID](https://github.com/oliver-ni/prefixed_id)","ref":"readme.html#alternatives"},{"type":"extras","title":"Copyright and License - PrefixedAPIKey","doc":"Copyright (c) 2022, 2025 Digital Identity Ltd, UK\n\nPrefixedAPIKey is MIT licensed.","ref":"readme.html#copyright-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}